#!/usr/bin/env python
# Copyright 2005 Paul Sladen <thinkpad@paul.sladen.org>, GPL

from OpenGL.GL import *

def draw_thinkpad(lid_angle = 110, keyboard = 0, nipple = 0):
    glPushMatrix()

    glTranslate(-1.34, -1.055, 0)

    glColor(0.3, 0.3, 0.3)

    glEnable(GL_CULL_FACE)
    glEnable(GL_DEPTH_TEST)
    glEnable(GL_LIGHTING)
    glLightfv(GL_LIGHT0, GL_POSITION, [-10, -10, 10]) # North West
    glLightfv(GL_LIGHT0, GL_DIFFUSE, [1.0, 1.0, 1.0])
    glLightf(GL_LIGHT0, GL_CONSTANT_ATTENUATION, 0.1)
    glLightf(GL_LIGHT0, GL_LINEAR_ATTENUATION, 0.05)
    glEnable(GL_LIGHT0)

    # X40 is 268mm x 211mm x 23.8mm, sloping from back to front

    SCALE = 0.01

    WIDTH = 268.0 * 0.01
    FRONT =  15.0 * 0.01
    BACK  =  20.0 * 0.01
    LID   =   5.0 * 0.01
    DEPTH = 211.0 * 0.01
    
    # Base
    glBegin(GL_QUAD_STRIP)
    if 1:
        # Left edge
        glVertex(    0, DEPTH,  BACK)
        glVertex(    0,     0, FRONT)
        # Right edge
        glVertex(WIDTH, DEPTH,  BACK)
        glVertex(WIDTH,     0, FRONT)
        # Right edge
        glVertex(WIDTH, DEPTH,     0)
        glVertex(WIDTH,     0,     0)
        # Left edge
        glVertex(    0, DEPTH,     0)
        glVertex(    0,     0,     0)
        # Left edge
        glVertex(    0, DEPTH,  BACK)
        glVertex(    0,     0, FRONT)
    glEnd()
    # Base Front + Back
    glBegin(GL_QUADS)
    if 1:
        # Front
        glVertex(    0,     0,     0)
        glVertex(WIDTH,     0,     0)
        glVertex(WIDTH,     0, FRONT)
        glVertex(    0,     0, FRONT)
        # Back
        glVertex(    0, DEPTH,     0)
        glVertex(    0, DEPTH,  BACK)
        glVertex(WIDTH, DEPTH,  BACK)
        glVertex(WIDTH, DEPTH,     0)
    glEnd()

    # This is the Lid which is hinged so that we can show open/closed
    # state.  It's basically a different-shaped box.  Note that with
    # the lid-shut (zero degrees), it doesn't quite sit flat with the
    # base unit.  If I modelled something else (T42) then that is a
    # flat model of laptop and not 'wedge' shaped for extra comfort.
    
    glPushMatrix()
    if 1:
        glTranslate(0, DEPTH, BACK)
        glRotate(180-lid_angle, 1, 0, 0)

        # Lid
        glBegin(GL_QUAD_STRIP)
        if 1:
            # Left edge
            glVertex(    0, DEPTH,   LID)
            glVertex(    0,     0,   LID)
            # Right edge
            glVertex(WIDTH, DEPTH,   LID)
            glVertex(WIDTH,     0,   LID)
            # Right edge
            glVertex(WIDTH, DEPTH,     0)
            glVertex(WIDTH,     0,     0)
            # Left edge
            glVertex(    0, DEPTH,     0)
            glVertex(    0,     0,     0)
            # Left edge
            glVertex(    0, DEPTH,   LID)
            glVertex(    0,     0,   LID)
        glEnd()
        # Base Front + Back
        glBegin(GL_QUADS)
        if 1:
            # Front
            glVertex(    0,     0,     0)
            glVertex(WIDTH,     0,     0)
            glVertex(WIDTH,     0,   LID)
            glVertex(    0,     0,   LID)
            # Back
            glVertex(    0, DEPTH,     0)
            glVertex(    0, DEPTH,   LID)
            glVertex(WIDTH, DEPTH,   LID)
            glVertex(WIDTH, DEPTH,     0)
        glEnd()

        glDisable(GL_LIGHTING)

        # Screen
        glColor(0.9, 0.9, 1.0)
        glBegin(GL_QUAD_STRIP)
        if 1:
            # Right edge
            glVertex(WIDTH-.10,   .25,  .06)
            glVertex(WIDTH-.10,  2.00,  .06)
            # Left edge
            glVertex(      .10,   .25,  .06)
            glVertex(      .10,  2.00,  .06)
        glEnd()
    glPopMatrix()

    # Keyboard
    if keyboard:
        glColor(0.5, 0.5, 0.5)
    else:
        glColor(0.3, 0.3, 0.3)
    glBegin(GL_QUAD_STRIP)
    if 1:
        # Left edge
        glVertex(      .20,  1.90, BACK    )
        glVertex(      .20,  0.70, BACK-.02)
        # Right edge
        glVertex(WIDTH-.20,  1.90, BACK    )
        glVertex(WIDTH-.20,  0.70, BACK-.02)
    glEnd()

    # Nipple
    if nipple:
        glColor(0.9, 0.3, 0.3)
        glBegin(GL_QUAD_STRIP)
        if 1:
            # Left edge
            glVertex(1.20, 1.30, .201)
            glVertex(1.20, 1.10, .181)
            # Right edge
            glVertex(1.40, 1.30, .201)
            glVertex(1.40, 1.10, .181)
        glEnd()
    glPopMatrix()


